﻿/***********************************************************
 * Purpose:
 *		Intermediate application sample
 *		for use within Application Control Solution
 * 
 * Provided by Arellia Corporation
 ***********************************************************
 * DISCLAIMER:
 * 
 * You may freely use the attached Source Code and Object Code
 * compiled from it, with or without modification, but this 
 * Source Code is provided to you "AS IS" EXCLUSIVE OF ANY 
 * WARRANTY, INCLUDING, WITHOUT LIMITATION, ANY WARRANTIES 
 * OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, 
 * OR ANY OTHER WARRANTY, WHETHER EXPRESS OR IMPLIED. IN NO
 * EVENT WILL ARELLIA CORPORATION HAVE ANY LIABILITY FOR ANY
 * LOST PROFITS, LOSS OF DATA OR COSTS OF PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES, OR FOR ANY SPECIAL,
 * INDIRECT, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THIS
 * AGREEMENT, INCLUDING, WITHOUT LIMITATION, THOSE RESULTING
 * FROM THE USE OF THE SOURCE CODE, OR THE FAILURE OF THE
 * SOURCE CODE TO PERFORM, OR FOR ANY OTHER REASON.
 * 
 * Arellia Corporation reserves the right to include
 * (in portions or entirety) this intermediate application
 * and/or source code in future versions of products.
 *
 **********************************************************/
using System;
using System.Linq;
using System.Windows;
using System.Windows.Threading;

namespace Justify
{
	/// <summary>
	/// Interaction logic for App.xaml
	/// </summary>
	public partial class App : Application
	{
		/// <summary>
		/// The unsuccessful exit code for the application.
		/// </summary>
		public static readonly int ErrorExitCode = 100;

		/// <summary>
		/// Gets an array of the process arguments used to launch this application.
		/// </summary>
		public string[] Arguments { get; private set; }

		/// <summary>
		/// Gets or sets the flag indicating whether to exit with a
		/// successful (0) or unsuccessful (100) error code.
		/// </summary>
		public bool IsSuccess { get; set; }



		protected override void OnStartup(StartupEventArgs e)
		{
			base.OnStartup(e);

			DispatcherUnhandledException += OnDispatcherUnhandledException;
			Arguments = e.Args;
		}

		protected override void OnExit(ExitEventArgs e)
		{
			e.ApplicationExitCode = IsSuccess ? 0 : ErrorExitCode;
			base.OnExit(e);
		}

		private void OnDispatcherUnhandledException(object sender, DispatcherUnhandledExceptionEventArgs e)
		{
			MessageBox.Show(string.Format("Application Error: " + e.Exception));
			Shutdown(ErrorExitCode);
		}

	}
}
