﻿/***********************************************************
 * Purpose:
 *		Intermediate application sample
 *		for use within Application Control Solution
 * 
 * Provided by Arellia Corporation
 ***********************************************************
 * DISCLAIMER:
 * 
 * You may freely use the attached Source Code and Object Code
 * compiled from it, with or without modification, but this 
 * Source Code is provided to you "AS IS" EXCLUSIVE OF ANY 
 * WARRANTY, INCLUDING, WITHOUT LIMITATION, ANY WARRANTIES 
 * OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, 
 * OR ANY OTHER WARRANTY, WHETHER EXPRESS OR IMPLIED. IN NO
 * EVENT WILL ARELLIA CORPORATION HAVE ANY LIABILITY FOR ANY
 * LOST PROFITS, LOSS OF DATA OR COSTS OF PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES, OR FOR ANY SPECIAL,
 * INDIRECT, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THIS
 * AGREEMENT, INCLUDING, WITHOUT LIMITATION, THOSE RESULTING
 * FROM THE USE OF THE SOURCE CODE, OR THE FAILURE OF THE
 * SOURCE CODE TO PERFORM, OR FOR ANY OTHER REASON.
 * 
 * Arellia Corporation reserves the right to include
 * (in portions or entirety) this intermediate application
 * and/or source code in future versions of products.
 *
 **********************************************************/
using System;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Security.Cryptography;

namespace Justify
{
	public class FileUtils
	{
		/// <summary>
		/// Computes the SHA-1 hash of a file.
		/// </summary>
		/// <param name="filepath">Pathname to the file.</param>
		/// <returns>Base64 encoded SHA-1 hash of the file.</returns>
		public static string ComputeFileHash(string filepath)
		{
			using ( var stream = new FileStream(filepath, FileMode.Open, FileAccess.Read) )
			{
				HashAlgorithm sha1Hasher = new SHA1CryptoServiceProvider();
				byte[] hashBytes = sha1Hasher.ComputeHash(stream);
				stream.Close();

				string hash = Convert.ToBase64String(hashBytes);
				return hash;
			}
		}

		/// <summary>
		/// Gets the full path to the process.
		/// </summary>
		/// <param name="processId">Identifier of the process.</param>
		/// <returns></returns>
		public static string GetFilePathOfProcess(int processId)
		{
			Process process = Process.GetProcessById(processId);
			return process.MainModule.FileName;
		}

		/// <summary>
		/// Gets the application name of a running process.
		/// </summary>
		/// <param name="processId">Identifier of the process.</param>
		/// <returns></returns>
		public static string GetNameOfProcess(int processId)
		{
			Process process = Process.GetProcessById(processId);
			return process.ProcessName;
		}

	}
}
